@@ -6,8 +6,7 @@
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef ALARMLISTDELEGATE_H
-#define ALARMLISTDELEGATE_H
+#pragma once
 
 #include "alarmlistview.h"
 
@@ -26,6 +25,5 @@ private:
     QRect textRect(const QString& text, QPainter*, const QStyleOptionViewItem&) const;
 };
 
-#endif
 
 // vim: et sw=4:
