@@ -13,10 +13,10 @@
 
 #include <KAlarmCal/KAEvent>
 
-#include <AkonadiCore/ChangeRecorder>
-#include <AkonadiCore/EntityDisplayAttribute>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/Session>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/Session>
 #include <KContacts/Addressee>
 
 #include <QLocale>
