@@ -11,8 +11,7 @@
  *  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef DAYMATRIX_H
-#define DAYMATRIX_H
+#pragma once
 
 #include "editdlg.h"
 
@@ -74,7 +73,7 @@ Q_SIGNALS:
     void selected(const QVector<QDate>& dates);
 
     void newAlarm(EditAlarmDlg::Type);
-    void newAlarmFromTemplate(const KAEvent&);
+    void newAlarmFromTemplate(const KAlarmCal::KAEvent&);
 
 protected:
     bool event(QEvent*) override;
@@ -128,6 +127,5 @@ private:
     bool   mPendingChanges {false};   // the display needs to be updated
 };
 
-#endif // DAYMATRIX_H
 
 // vim: et sw=4:
