@@ -14,6 +14,7 @@
 #include "lib/checkbox.h"
 
 #include <KFontChooser>
+#include <kwidgetsaddons_version.h>
 
 #include <QGroupBox>
 #include <QLabel>
@@ -86,7 +87,10 @@ FontColourChooser::FontColourChooser(QWidget* parent, const QStringList& fontLis
         layout->addWidget(new QWidget(page));    // left adjust the widget
     }
 
-    mFontChooser = new KFontChooser(page, KFontChooser::DisplayFrame, fontList, visibleListSize);
+    mFontChooser = new KFontChooser(KFontChooser::DisplayFrame, page);
+    mFontChooser->setFontListItems(fontList);
+    mFontChooser->setMinVisibleItems(visibleListSize);
+
     mFontChooser->installEventFilter(this);   // for read-only mode
     QList<QWidget*> kids = mFontChooser->findChildren<QWidget*>();
     for (int i = 0, end = kids.count();  i < end;  ++i)
