@@ -1,21 +1,9 @@
 /*
  *  label.cpp  -  label with radiobutton buddy option
  *  Program:  kalarm
- *  Copyright © 2004-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "label.h"
@@ -34,7 +22,7 @@ Label::Label(const QString& text, QWidget* parent, Qt::WindowFlags f)
 Label::Label(QWidget* buddy, const QString& text, QWidget* parent, Qt::WindowFlags f)
     : QLabel(text, parent, f)
 {
-    setBuddy(buddy);
+    Label::setBuddy(buddy);
 }
 
 /******************************************************************************
@@ -108,7 +96,7 @@ LabelFocusWidget::LabelFocusWidget(QWidget* parent)
 
 void LabelFocusWidget::focusInEvent(QFocusEvent*)
 {
-    Label* parent = (Label*)parentWidget();
+    auto* parent = (Label*)parentWidget();
     parent->activated();
 
 }
