@@ -8,9 +8,10 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIGRATEKDE4FILES_H
-#define MIGRATEKDE4FILES_H
-
+#pragma once
+#include <QObject>
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <PimCommon/MigrateApplicationFiles>
 
 /** Class to migrate KAlarm config and data files from KDE4 locations to Qt5
@@ -28,7 +29,6 @@ private:
 
     PimCommon::MigrateApplicationFiles mMigrator;
 };
-
-#endif // MIGRATEKDE4FILES_H
+#endif
 
 // vim: et sw=4:
