@@ -6,8 +6,7 @@
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef FILERESOURCECONFIGMANAGER_H
-#define FILERESOURCECONFIGMANAGER_H
+#pragma once
 
 #include "resource.h"
 #include "fileresource.h"
@@ -76,7 +75,7 @@ private:
         FileResourceSettings::Ptr settings;
 
         ResourceData() {}
-        ResourceData(Resource r, FileResourceSettings::Ptr s) : resource(r), settings(s) {}
+        ResourceData(const Resource &r, FileResourceSettings::Ptr s) : resource(r), settings(s) {}
         ResourceData(const ResourceData&) = default;
         ResourceData& operator=(const ResourceData&) = default;
     };
@@ -88,6 +87,5 @@ private:
     int                             mCreated {0};    // 1 = createResources() has been run, 2 = completed
 };
 
-#endif // FILERESOURCECONFIGMANAGER_H
 
 // vim: et sw=4:
