@@ -54,6 +54,11 @@ bool Resource::failed() const
     return mResource.isNull() ? true : mResource->failed();
 }
 
+bool Resource::inError() const
+{
+    return mResource.isNull() ? true : mResource->inError();
+}
+
 ResourceId Resource::id() const
 {
     return mResource.isNull() ? -1 : mResource->id();
@@ -294,6 +299,12 @@ void Resource::handleCommandErrorChange(const KAEvent& event)
         mResource->handleCommandErrorChange(event);
 }
 
+void Resource::removeSettings()
+{
+    if (!mResource.isNull())
+        mResource->removeSettings();
+}
+
 void Resource::notifyDeletion()
 {
     if (!mResource.isNull())
