@@ -57,6 +57,11 @@ public:
      */
     bool failed() const;
 
+    /** Return whether the resource has an error (fatal or non-fatal), and
+     *  cannot currently be used. This will be true if failed() is true.
+     */
+    bool inError() const;
+
     /** Return the resource's unique ID. */
     ResourceId id() const;
 
@@ -345,6 +350,9 @@ public:
     /** Called to notify the resource that an event's command error has changed. */
     void handleCommandErrorChange(const KAEvent&);
 
+    /** Called when the resource's settings object is about to be destroyed. */
+    void removeSettings();
+
     /** Must be called to notify the resource that it is being deleted.
      *  This is to prevent expected errors being displayed to the user.
      *  @see isBeingDeleted
