@@ -53,6 +53,22 @@ Resource Resources::resource(ResourceId id)
     return mResources.value(id, Resource::null());
 }
 
+Resource Resources::resourceFromDisplayId(ResourceId id)
+{
+    Resource result = Resource::null();
+    for (auto it = mResources.constBegin();  it != mResources.constEnd();  ++it)
+    {
+        const Resource& res = it.value();
+        if (res.displayId() == id)
+        {
+            if (result != Resource::null())
+                return Resource::null();
+            result = res;
+        }
+    }
+    return result;
+}
+
 /******************************************************************************
 * Return the resources which are enabled for a specified alarm type.
 * If 'writable' is true, only writable resources are included.
@@ -378,7 +394,7 @@ void Resources::notifyResourcesCreated()
 }
 
 /******************************************************************************
-* Called when a resource's events have been loaded.
+* Called when a resource's events have been loaded, or when loading fails.
 * Emits a signal if all collections have been populated.
 */
 void Resources::notifyResourcePopulated(const ResourceType* res)
@@ -386,7 +402,7 @@ void Resources::notifyResourcePopulated(const ResourceType* res)
     if (res)
     {
         Resource r = resource(res->id());
-        if (r.isValid())
+        if (r.isValid()  &&  !r.inError())
             Q_EMIT instance()->resourcePopulated(r);
     }
 
@@ -554,6 +570,13 @@ void Resources::notifyEventsRemoved(ResourceType* res, const QList<KAEvent>& eve
     }
 }
 
+void Resources::notifySettingsDestroyed(ResourceId id)
+{
+    Resource r = resource(id);
+    if (r.isValid())
+        r.removeSettings();
+}
+
 bool Resources::addResource(ResourceType* instance, Resource& resource)
 {
     if (!instance  ||  instance->id() < 0)
@@ -585,17 +608,18 @@ void Resources::removeResource(ResourceId id)
 
 /******************************************************************************
 * To be called when a resource has been created or loaded.
-* If all resources have now loaded for the first time, emit signal.
+* If all resources have now loaded for the first time, or cannot currently be
+* loaded, emit signal.
 */
 void Resources::checkResourcesPopulated()
 {
     if (!mPopulated  &&  mCreated)
     {
-        // Check whether all resources have now loaded at least once.
+        // Check whether all resources have now loaded at least once, or cannot currently be loaded.
         for (auto it = mResources.constBegin();  it != mResources.constEnd();  ++it)
         {
             const Resource& res = it.value();
-            if (res.isEnabled(CalEvent::EMPTY)  &&  !res.isPopulated())
+            if (res.isEnabled(CalEvent::EMPTY)  &&  !res.inError()  &&  !res.isPopulated())
                 return;
         }
         mPopulated = true;
