@@ -38,6 +38,12 @@ public:
      */
     static Resource resource(ResourceId);
 
+    /** Return a copy of the resource with a given display ID.
+     *  @return  The resource, or invalid if the ID doesn't already exist or is invalid
+     *           or if more than one resource has the same display ID.
+     */
+    static Resource resourceFromDisplayId(ResourceId);
+
     /** Remove a resource. The calendar file is not removed.
      *  @return true if the resource has been removed or a removal job has been scheduled.
      */
@@ -164,7 +170,8 @@ public:
      *  been created. */
     static void notifyResourcesCreated();
 
-    /** Called by a resource to notify that loading of events has successfully completed. */
+    /** Called by a resource to notify that loading of events has successfully completed,
+     *  or that loading has failed. */
     static void notifyResourcePopulated(const ResourceType*);
 
     /** Called to notify that a resource is about to be removed. */
@@ -203,6 +210,9 @@ public:
     /** Called by a resource to notify that it has deleted events. */
     static void notifyEventsRemoved(ResourceType*, const QList<KAEvent>&);
 
+    /** Called by a resource settings instance to notify that it is about to be destructed. */
+    static void notifySettingsDestroyed(ResourceId);
+
 Q_SIGNALS:
     /** Emitted when a resource's settings have changed. */
     void settingsChanged(Resource&, ResourceType::Changes);
@@ -214,7 +224,8 @@ Q_SIGNALS:
     void resourcesCreated();
 
     /** Emitted when all configured and migrated resources have been loaded for
-     *  the first time. This is always emitted after resourcesCreated().
+     *  the first time, or cannot currently be loaded.
+     *  This is always emitted after resourcesCreated().
      */
     void resourcesPopulated();
 
