@@ -30,6 +30,11 @@ bool ResourceType::failed() const
     return mFailed  ||  !isValid();
 }
 
+bool ResourceType::inError() const
+{
+    return mInError  ||  failed();
+}
+
 ResourceId ResourceType::displayId() const
 {
     return id();
@@ -318,8 +323,7 @@ void ResourceType::setLoaded(bool loaded) const
     if (loaded != mLoaded)
     {
         mLoaded = loaded;
-        if (loaded)
-            Resources::notifyResourcePopulated(this);
+        Resources::notifyResourcePopulated(this);
     }
 }
 
@@ -328,6 +332,11 @@ void ResourceType::setFailed()
     mFailed = true;
 }
 
+void ResourceType::setError(bool error)
+{
+    mInError = error;
+}
+
 QString ResourceType::storageTypeString(StorageType type)
 {
     switch (type)
