@@ -90,6 +90,11 @@ public:
      */
     bool failed() const;
 
+    /** Return whether the resource has an error (fatal or non-fatal), and
+     *  cannot currently be used. This will be true if failed() is true.
+     */
+    bool inError() const;
+
     /** Return the resource's unique ID. */
     ResourceId id() const    { return mId; }
 
@@ -387,6 +392,9 @@ public:
     /** Called to notify the resource that an event's command error has changed. */
     virtual void handleCommandErrorChange(const KAEvent&) = 0;
 
+    /** Called when the resource's settings object is about to be destroyed. */
+    virtual void removeSettings()  {}
+
     /** Must be called to notify the resource that it is being deleted.
      *  This is to prevent expected errors being displayed to the user.
      *  @see isBeingDeleted
@@ -454,6 +462,11 @@ protected:
      */
     void setFailed();
 
+    /** To be called if the resource has encountered a non-fatal error.
+     *  A non-fatal error is one that can be recovered from.
+     */
+    void setError(bool error);
+
     static QString storageTypeStr(bool description, bool file, bool local);
 
     template <class T> static T* resource(Resource&);
@@ -468,6 +481,7 @@ private:
     QList<KAEvent> mEventsUpdated;       // events updated in mEvents but not yet notified
     ResourceId   mId {-1};               // resource's ID, which can't be changed
     bool         mFailed {false};        // the resource has a fatal error
+    bool         mInError {false};       // the resource has a non-fatal error
     mutable bool mLoaded {false};        // the resource has finished loading
     bool         mBeingDeleted {false};  // the resource is currently being deleted
 };
