@@ -50,7 +50,8 @@ SoundDlg::SoundDlg(const QString& file, float volume, float fadeVolume, int fade
     : QDialog(parent)
 {
     auto layout = new QVBoxLayout(this);
-    mSoundWidget = new SoundWidget(true, true, this);
+    const QString repWhatsThis = i18nc("@info:whatsthis", "If checked, the sound file will be played repeatedly for as long as the message is displayed.");
+    mSoundWidget = new SoundWidget(true, repWhatsThis, this);
     layout->addWidget(mSoundWidget);
 
     mButtonBox = new QDialogButtonBox;
@@ -136,8 +137,9 @@ void SoundDlg::slotButtonClicked(QAbstractButton* button)
 =============================================================================*/
 QString SoundWidget::mDefaultDir;
 
-SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
+SoundWidget::SoundWidget(bool showPlay, const QString& repeatWhatsThis, QWidget* parent)
     : QWidget(parent)
+    , mRepeatWhatsThis(repeatWhatsThis)
 {
     auto layout = new QVBoxLayout(this);
 
@@ -178,8 +180,6 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
     mFileBrowseButton = new PushButton(box);
     boxHLayout->addWidget(mFileBrowseButton);
     mFileBrowseButton->setIcon(QIcon(QIcon::fromTheme(QStringLiteral("document-open"))));
-    const int size = mFileBrowseButton->sizeHint().height();
-    mFileBrowseButton->setFixedSize(size, size);
     connect(mFileBrowseButton, &PushButton::clicked, this, &SoundWidget::slotPickFile);
     mFileBrowseButton->setToolTip(i18nc("@info:tooltip", "Choose a file"));
     mFileBrowseButton->setWhatsThis(i18nc("@info:whatsthis", "Select a sound file to play."));
@@ -191,35 +191,29 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
         mFileBrowseButton->setFixedSize(size, size);
     }
 
-    if (showRepeat)
-    {
-        // Sound repetition checkbox
-        mRepeatGroupBox = new GroupBox(i18n_chk_Repeat(), this);
-        mRepeatGroupBox->setCheckable(true);
-        mRepeatGroupBox->setWhatsThis(i18nc("@info:whatsthis", "If checked, the sound file will be played repeatedly for as long as the message is displayed."));
-        connect(mRepeatGroupBox, &GroupBox::toggled, this, &SoundWidget::changed);
-        layout->addWidget(mRepeatGroupBox);
-        auto glayout = new QVBoxLayout(mRepeatGroupBox);
+    // Sound repetition checkbox
+    mRepeatGroupBox = new GroupBox(i18n_chk_Repeat(), this);
+    mRepeatGroupBox->setCheckable(true);
+    mRepeatGroupBox->setWhatsThis(mRepeatWhatsThis);
+    connect(mRepeatGroupBox, &GroupBox::toggled, this, &SoundWidget::changed);
+    layout->addWidget(mRepeatGroupBox);
+    auto glayout = new QVBoxLayout(mRepeatGroupBox);
 
-        // Pause between repetitions
-        QWidget* box = new QWidget(mRepeatGroupBox);
-        glayout->addWidget(box, 0, Qt::AlignLeft);
-        boxHLayout = new QHBoxLayout(box);
-        boxHLayout->setContentsMargins(0, 0, 0, 0);
-        label = new QLabel(i18nc("@label:spinbox Length of time to pause between repetitions", "Pause between repetitions:"), box);
-        boxHLayout->addWidget(label);
-        label->setFixedSize(label->sizeHint());
-        mRepeatPause = new SpinBox(0, 999, box);
-        boxHLayout->addWidget(mRepeatPause);
-        mRepeatPause->setSingleShiftStep(10);
-        mRepeatPause->setFixedSize(mRepeatPause->sizeHint());
-        label->setBuddy(mRepeatPause);
-        connect(mRepeatPause, &SpinBox::valueChanged, this, &SoundWidget::changed);
-        label = new QLabel(i18nc("@label", "seconds"), box);
-        boxHLayout->addWidget(label);
-        label->setFixedSize(label->sizeHint());
-        box->setWhatsThis(i18nc("@info:whatsthis", "Enter how many seconds to pause between repetitions."));
-    }
+    // Pause between repetitions
+    box = new QWidget(mRepeatGroupBox);
+    glayout->addWidget(box, 0, Qt::AlignLeft);
+    boxHLayout = new QHBoxLayout(box);
+    boxHLayout->setContentsMargins(0, 0, 0, 0);
+    label = new QLabel(i18nc("@label:spinbox Length of time to pause between repetitions", "Pause between repetitions:"), box);
+    boxHLayout->addWidget(label);
+    mRepeatPause = new SpinBox(0, 999, box);
+    boxHLayout->addWidget(mRepeatPause);
+    mRepeatPause->setSingleShiftStep(10);
+    label->setBuddy(mRepeatPause);
+    connect(mRepeatPause, &SpinBox::valueChanged, this, &SoundWidget::changed);
+    label = new QLabel(i18nc("@label", "seconds"), box);
+    boxHLayout->addWidget(label);
+    box->setWhatsThis(i18nc("@info:whatsthis", "Enter how many seconds to pause between repetitions."));
 
     // Volume
     QGroupBox* group = new QGroupBox(i18nc("@title:group Sound volume", "Volume"), this);
@@ -237,7 +231,6 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
     boxHLayout->setContentsMargins(0, 0, 0, 0);
     mVolumeCheckbox = new CheckBox(i18n_chk_SetVolume(), box);
     boxHLayout->addWidget(mVolumeCheckbox);
-    mVolumeCheckbox->setFixedSize(mVolumeCheckbox->sizeHint());
     connect(mVolumeCheckbox, &CheckBox::toggled, this, &SoundWidget::slotVolumeToggled);
     mVolumeCheckbox->setWhatsThis(i18nc("@info:whatsthis", "Select to choose the volume for playing the sound file."));
 
@@ -256,7 +249,6 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
 
     // Fade checkbox
     mFadeCheckbox = new CheckBox(i18nc("@option:check", "Fade"), group);
-    mFadeCheckbox->setFixedSize(mFadeCheckbox->sizeHint());
     connect(mFadeCheckbox, &CheckBox::toggled, this, &SoundWidget::slotFadeToggled);
     mFadeCheckbox->setWhatsThis(i18nc("@info:whatsthis", "Select to fade the volume when the sound file first starts to play."));
     grid->addWidget(mFadeCheckbox, 2, 1, 1, 2, Qt::AlignLeft);
@@ -268,16 +260,13 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
     boxHLayout->setContentsMargins(0, 0, 0, 0);
     label = new QLabel(i18nc("@label:spinbox Time period over which to fade the sound", "Fade time:"), mFadeBox);
     boxHLayout->addWidget(label);
-    label->setFixedSize(label->sizeHint());
     mFadeTime = new SpinBox(1, 999, mFadeBox);
     boxHLayout->addWidget(mFadeTime);
     mFadeTime->setSingleShiftStep(10);
-    mFadeTime->setFixedSize(mFadeTime->sizeHint());
     label->setBuddy(mFadeTime);
     connect(mFadeTime, &SpinBox::valueChanged, this, &SoundWidget::changed);
     label = new QLabel(i18nc("@label", "seconds"), mFadeBox);
     boxHLayout->addWidget(label);
-    label->setFixedSize(label->sizeHint());
     mFadeBox->setWhatsThis(i18nc("@info:whatsthis", "Enter how many seconds to fade the sound before reaching the set volume."));
 
     // Fade slider
@@ -287,7 +276,6 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
     boxHLayout->setContentsMargins(0, 0, 0, 0);
     label = new QLabel(i18nc("@label:slider", "Initial volume:"), mFadeVolumeBox);
     boxHLayout->addWidget(label);
-    label->setFixedSize(label->sizeHint());
     mFadeSlider = new Slider(0, 100, 10, Qt::Horizontal, mFadeVolumeBox);
     boxHLayout->addWidget(mFadeSlider);
     mFadeSlider->setTickPosition(QSlider::TicksBelow);
